@@ -4,7 +4,7 @@
 #' @importFrom stringr str_extract %>%
 #' @importFrom stats na.omit
 #' @param Model A trained model.
-#' @return A data frame
+#' @return A list
 #' @examples
 #' xgboost <- XGBoostModel(SplitRatio = 0.2,
 #'                         CV = 2,
@@ -13,7 +13,7 @@
 #' ModelMetrics(Model = xgboost)
 
 ModelMetrics <- function(Model) {
-
+  
   AverageCV <- function(results){
     mlm <- do.call(cbind, results)
     colnames(mlm) <- gsub("Fold[0-9]{1,2}.", "", colnames(mlm))
@@ -22,28 +22,34 @@ ModelMetrics <- function(Model) {
       name <- unique(colnames(mlm))[i]
       num <- grep(name, colnames(mlm))
       acc[[i]] <- rowMeans(mlm[,num])
-
+      
     }
     result <- round(do.call(cbind, acc),3)
     colnames(result) <- unique(colnames(mlm))
     return(result)
   }
-
+  
+  Mode <- function(x) {
+    ux <- unique(x)
+    return(ux[which.max(tabulate(match(x, ux)))][[1]])
+  }
+  
   if(!is.list(Model)) {
     stop('Please provide the model.')
   }
   model_type <- str_extract(names(Model)[1], "Fold.*") %>%
     na.omit() %>%
     length()
-
+  
   if(model_type != 0) {
-  results <- list()
-  for(i in seq_along(Model)) {
-    results[[names(Model)[i]]] <- Model[[i]][["result"]]
-  }
-  return(AverageCV(results))
+    confusionmat <- list()  
+    results <- list()
+    for(i in seq_along(Model)) {
+      results[[names(Model)[i]]] <- Model[[i]][["result"]]
+      confusionmat[[names(Model)[i]]] <- Model[[i]][["ConfusionMat"]]
+    }
+    return(list(ConfusionMatrix = Mode(confusionmat), ModelPerformance = AverageCV(results)))
   } else {
-    results <- list(result = Model[["result"]], result = Model[["result"]])
-    return(AverageCV(results))
-}
+    return(list(ConfusionMatrix = Model[["ConfusionMat"]], ModelPerformance = Model[["result"]]))
+  }
 }
